summaryrefslogtreecommitdiff
path: root/riscos/toolbar.h
diff options
context:
space:
mode:
Diffstat (limited to 'riscos/toolbar.h')
-rw-r--r--riscos/toolbar.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/riscos/toolbar.h b/riscos/toolbar.h
index 336f95d15..41f1af728 100644
--- a/riscos/toolbar.h
+++ b/riscos/toolbar.h
@@ -428,15 +428,15 @@ void ro_toolbar_set_site_favicon(struct toolbar *toolbar,
/**
* Update the favicon in a browser window toolbar to reflect the RISC OS
* filetype of the supplied content. If the toolbar currently has a
* site favicon set, then this call will be ignored.
*
* \param *toolbar The toolbar to refresh.
- * \param *h The page content to reflect.
+ * \param *g The gui window to set content favicon for.
*/
void ro_toolbar_set_content_favicon(struct toolbar *toolbar,
- struct hlcache_handle *h);
+ struct gui_window *g);
/**
@@ -428,15 +428,15 @@ void ro_toolbar_set_site_favicon(struct toolbar *toolbar,
/**
* Update the favicon in a browser window toolbar to reflect the RISC OS
- * filetype of the supplied content. If the toolbar currently has a
- * site favicon set, then this call will be ignored.
+ * filetype of the content within the supplied window. If the toolbar
+ * currently has a site favicon set, then this call will be ignored.
*
* \param *toolbar The toolbar to refresh.